@@ -247,7 +247,9 @@ module Aws
           {
             'ACM' => 'acm',
             'ACMPCA' => 'acm-pca',
+            'AIOps' => 'aiops',
             'APIGateway' => 'apigateway',
+            'ARCRegionswitch' => 'arc-region-switch',
             'ARCZonalShift' => 'arc-zonal-shift',
             'AccessAnalyzer' => 'access-analyzer',
             'Account' => 'account',
@@ -279,14 +281,23 @@ module Aws
             'AutoScaling' => 'autoscaling',
             'AutoScalingPlans' => 'autoscaling-plans',
             'B2bi' => 'b2bi',
+            'BCMDashboards' => 'bcm-dashboards',
             'BCMDataExports' => 'bcm-data-exports',
+            'BCMPricingCalculator' => 'bcm-pricing-calculator',
+            'BCMRecommendedActions' => 'bcm-recommended-actions',
             'Backup' => 'backup',
             'BackupGateway' => 'backup-gateway',
+            'BackupSearch' => 'backup-search',
             'Batch' => 'batch',
             'Bedrock' => 'bedrock',
             'BedrockAgent' => 'bedrock-agent',
+            'BedrockAgentCore' => 'bedrock-agentcore',
+            'BedrockAgentCoreControl' => 'bedrock-agentcore-control',
             'BedrockAgentRuntime' => 'bedrock-agent-runtime',
+            'BedrockDataAutomation' => 'bedrock-data-automation',
+            'BedrockDataAutomationRuntime' => 'bedrock-data-automation-runtime',
             'BedrockRuntime' => 'bedrock-runtime',
+            'Billing' => 'billing',
             'BillingConductor' => 'billingconductor',
             'Braket' => 'braket',
             'Budgets' => 'budgets',
@@ -336,6 +347,7 @@ module Aws
             'ConfigService' => 'config',
             'Connect' => 'connect',
             'ConnectCampaignService' => 'connect-campaigns',
+            'ConnectCampaignsV2' => 'connect-campaigns',
             'ConnectCases' => 'cases',
             'ConnectContactLens' => 'contact-lens',
             'ConnectParticipant' => 'participant.connect',
@@ -348,6 +360,7 @@ module Aws
             'CustomerProfiles' => 'profile',
             'DAX' => 'dax',
             'DLM' => 'dlm',
+            'DSQL' => 'dsql',
             'DataExchange' => 'dataexchange',
             'DataPipeline' => 'datapipeline',
             'DataSync' => 'datasync',
@@ -379,13 +392,13 @@ module Aws
             'EMRServerless' => 'emr-serverless',
             'ElastiCache' => 'elasticache',
             'ElasticBeanstalk' => 'elasticbeanstalk',
-            'ElasticInference' => 'api.elastic-inference',
             'ElasticLoadBalancing' => 'elasticloadbalancing',
             'ElasticLoadBalancingV2' => 'elasticloadbalancing',
             'ElasticTranscoder' => 'elastictranscoder',
             'ElasticsearchService' => 'es',
             'EntityResolution' => 'entityresolution',
             'EventBridge' => 'events',
+            'Evs' => 'evs',
             'FIS' => 'fis',
             'FMS' => 'fms',
             'FSx' => 'fsx',
@@ -397,6 +410,7 @@ module Aws
             'FraudDetector' => 'frauddetector',
             'FreeTier' => 'freetier',
             'GameLift' => 'gamelift',
+            'GameLiftStreams' => 'gameliftstreams',
             'GeoMaps' => 'geo-maps',
             'GeoPlaces' => 'geo-places',
             'GeoRoutes' => 'geo-routes',
@@ -420,9 +434,8 @@ module Aws
             'Inspector2' => 'inspector2',
             'InspectorScan' => 'inspector-scan',
             'InternetMonitor' => 'internetmonitor',
+            'Invoicing' => 'invoicing',
             'IoT' => 'iot',
-            'IoT1ClickDevicesService' => 'devices.iot1click',
-            'IoT1ClickProjects' => 'projects.iot1click',
             'IoTAnalytics' => 'iotanalytics',
             'IoTDeviceAdvisor' => 'api.iotdeviceadvisor',
             'IoTEvents' => 'iotevents',
@@ -430,6 +443,7 @@ module Aws
             'IoTFleetHub' => 'api.fleethub.iot',
             'IoTFleetWise' => 'iotfleetwise',
             'IoTJobsDataPlane' => 'data.jobs.iot',
+            'IoTManagedIntegrations' => 'api.iotmanagedintegrations',
             'IoTSecureTunneling' => 'api.tunneling.iot',
             'IoTSiteWise' => 'iotsitewise',
             'IoTThingsGraph' => 'iotthingsgraph',
@@ -442,6 +456,7 @@ module Aws
             'Kendra' => 'kendra',
             'KendraRanking' => 'kendra-ranking',
             'Keyspaces' => 'cassandra',
+            'KeyspacesStreams' => 'cassandra-streams',
             'Kinesis' => 'kinesis',
             'KinesisAnalytics' => 'kinesisanalytics',
             'KinesisAnalyticsV2' => 'kinesisanalytics',
@@ -465,6 +480,7 @@ module Aws
             'LookoutEquipment' => 'lookoutequipment',
             'LookoutMetrics' => 'lookoutmetrics',
             'LookoutforVision' => 'lookoutvision',
+            'MPA' => 'mpa',
             'MQ' => 'mq',
             'MTurk' => 'mturk-requester',
             'MWAA' => 'airflow',
@@ -503,20 +519,24 @@ module Aws
             'NeptuneGraph' => 'neptune-graph',
             'Neptunedata' => 'neptune-db',
             'NetworkFirewall' => 'network-firewall',
+            'NetworkFlowMonitor' => 'networkflowmonitor',
             'NetworkManager' => 'networkmanager',
             'NetworkMonitor' => 'networkmonitor',
+            'Notifications' => 'notifications',
+            'NotificationsContacts' => 'notifications-contacts',
             'OAM' => 'oam',
             'OSIS' => 'osis',
+            'ObservabilityAdmin' => 'observabilityadmin',
+            'Odb' => 'odb',
             'Omics' => 'omics',
             'OpenSearchServerless' => 'aoss',
             'OpenSearchService' => 'es',
-            'OpsWorks' => 'opsworks',
-            'OpsWorksCM' => 'opsworks-cm',
             'Organizations' => 'organizations',
             'Outposts' => 'outposts',
             'PCS' => 'pcs',
             'PI' => 'pi',
             'Panorama' => 'panorama',
+            'PartnerCentralSelling' => 'partnercentral-selling',
             'PaymentCryptography' => 'controlplane.payment-cryptography',
             'PaymentCryptographyData' => 'dataplane.payment-cryptography',
             'PcaConnectorAd' => 'pca-connector-ad',
@@ -531,7 +551,6 @@ module Aws
             'Pipes' => 'pipes',
             'Polly' => 'polly',
             'Pricing' => 'api.pricing',
-            'PrivateNetworks' => 'private-networks',
             'PrometheusService' => 'aps',
             'Proton' => 'proton',
             'QApps' => 'data.qapps',
@@ -543,6 +562,7 @@ module Aws
             'RAM' => 'ram',
             'RDS' => 'rds',
             'RDSDataService' => 'rds-data',
+            'RTBFabric' => 'rtbfabric',
             'RecycleBin' => 'rbin',
             'Redshift' => 'redshift',
             'RedshiftDataAPIService' => 'redshift-data',
@@ -565,13 +585,15 @@ module Aws
             'S3' => 's3',
             'S3Control' => 's3-control',
             'S3Outposts' => 's3-outposts',
+            'S3Tables' => 's3tables',
+            'S3Vectors' => 's3vectors',
             'SES' => 'email',
             'SESV2' => 'email',
-            'SMS' => 'sms',
             'SNS' => 'sns',
             'SQS' => 'sqs',
             'SSM' => 'ssm',
             'SSMContacts' => 'ssm-contacts',
+            'SSMGuiConnect' => 'ssm-guiconnect',
             'SSMIncidents' => 'ssm-incidents',
             'SSMQuickSetup' => 'ssm-quicksetup',
             'SSO' => 'portal.sso',
@@ -590,6 +612,7 @@ module Aws
             'Schemas' => 'schemas',
             'SecretsManager' => 'secretsmanager',
             'SecurityHub' => 'securityhub',
+            'SecurityIR' => 'security-ir',
             'SecurityLake' => 'securitylake',
             'ServerlessApplicationRepository' => 'serverlessrepo',
             'ServiceCatalog' => 'servicecatalog',
@@ -633,6 +656,7 @@ module Aws
             'WorkSpaces' => 'workspaces',
             'WorkSpacesThinClient' => 'thinclient',
             'WorkSpacesWeb' => 'workspaces-web',
+            'WorkspacesInstances' => 'workspaces-instances',
             'XRay' => 'xray',
           }
           # end service ids
